AUTHORS = ('Author Information', {
    'fields': ('authors', 'authors_override', 'authors_extra'),
})

PUBLICATION = ('Publication Information', {
    'fields': ('pub_date', 'pub_status', 'sites', ),
})

TAXONOMY = ('Taxonomy', {
    'fields': ('sections', 'tags', ),
})
